%define pkgname		OpenXR-SDK-Source
%define openxrname	openxr
%define libmajor	1
%define libname		%mklibname %{openxrname} %{libmajor}
%define develname	%mklibname %{openxrname} -d

Name:		openxr
Version:	1.1.47
Release:	%mkrel 1
Summary:	An API for writing VR and AR software
Group:		Graphics/3D
License:	ASL 2.0
URL:		https://github.com/KhronosGroup/OpenXR-SDK-Source
Source:		https://github.com/KhronosGroup/%{pkgname}/archive/release-%{version}/%{pkgname}-release-%{version}.tar.gz
Patch1:		openxr-layer_install_dir.patch
# from git
BuildRequires:	cmake
BuildRequires:	glslang
BuildRequires:	glslang-devel
BuildRequires:	ninja
BuildRequires:	vulkan-devel
BuildRequires:	pkgconfig(egl)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(jsoncpp)
BuildRequires:	pkgconfig(wayland-client)
BuildRequires:	pkgconfig(xxf86vm)
BuildRequires:	pkgconfig(xcb-icccm)
BuildRequires:	pkgconfig(xcb-keysyms)
BuildRequires:	pkgconfig(xcb)
BuildRequires:	pkgconfig(xcb-glx)
BuildRequires:	pkgconfig(xcb-randr)
BuildRequires:	pkgconfig(xcb-dri2)
BuildRequires:	pkgconfig(xrandr)
BuildRequires:	python3-jinja2

Conflicts:	%{_lib}openxr1 < 1.0.26-4

%description
OpenXR is an API specification for writing portable, cross-platform,
virtual reality (VR) and augmented reality (AR) software.

%package -n %{libname}
Summary:	Libraries for writing VR and AR software
Group:		System/Libraries
Requires:	%{name} >= %{version}

%description -n %{libname}
This package contains the library needed to run programs dynamically
linked with OpenXR.

%package -n %{develname}
Summary:	Headers and development files of the OpenXR library
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
Development files for the USD library. Install this package if you
want to compile applications using the OpenXR library.

%prep
%autosetup -p1 -n %{pkgname}-release-%{version}

%build
%cmake \
    -G Ninja \
    -DBUILD_ALL_EXTENSIONS:BOOL=ON \
    -DBUILD_WITH_STD_FILESYSTEM=OFF \
    -DBUILD_WITH_WAYLAND_HEADERS=ON \
    -DBUILD_LOADER:BOOL=ON \
    -DBUILD_TESTS:BOOL=ON \
    -DPRESENTATION_BACKEND:STRING=xlib \
    -DCMAKE_CXX_STANDARD=17 \
    -DDYNAMIC_LOADER:BOOL=ON \
    -DOPENGL_glx_LIBRARY:STRING=GL
%cmake_build

%install
%cmake_install

%files
%doc BUILDING.md CHANGELOG.SDK.md LICENSE README.md
%license LICENSE
%{_bindir}/*
# plugins like?
%dir %{_libdir}/openxr
%dir %{_libdir}/openxr/1
%dir %{_libdir}/openxr/1/api_layers
%{_libdir}/openxr/1/api_layers/*.so
%{_datadir}/openxr/
%{_mandir}/man1/*.1*

%files -n %{libname}
%license LICENSE
%{_libdir}/lib%{name}_loader.so.%{libmajor}{,.*}

%files -n %{develname}
%{_libdir}/lib%{name}_loader.so
%{_includedir}/%{name}/
%{_libdir}/cmake/%{name}/
%{_libdir}/pkgconfig/*.pc



%changelog
* Mon May 05 2025 daviddavid <daviddavid> 1.1.47-1.mga10
+ Revision: 2181029
- new version: 1.1.47
- rebuild for new jsoncpp 1.9.6

* Tue Dec 31 2024 daviddavid <daviddavid> 1.1.43-1.mga10
+ Revision: 2132114
- new version: 1.1.43

* Tue Nov 12 2024 ghibo <ghibo> 1.1.42-1.mga10
+ Revision: 2114671
- Update to version 1.1.42

* Sat Oct 19 2024 ghibo <ghibo> 1.1.41-1.mga10
+ Revision: 2108147
- Update to version 1.1.41

* Sat Jul 20 2024 daviddavid <daviddavid> 1.1.38-1.mga10
+ Revision: 2082160
- new version: 1.1.38
- move layer plugins to the main pkg

* Sun Oct 29 2023 daviddavid <daviddavid> 1.0.26-3.mga10
+ Revision: 2002565
- rebuild for new jsoncpp 1.9.5

* Sun Jun 11 2023 daviddavid <daviddavid> 1.0.26-2.mga9
+ Revision: 1961755
- remove unmaintained xf86misc support now disable by default (fix mga#31867)

* Fri Dec 09 2022 ghibo <ghibo> 1.0.26-1.mga9
+ Revision: 1919809
- Update to release 1.0.26

* Mon Sep 26 2022 ghibo <ghibo> 1.0.25-1.mga9
+ Revision: 1892536
- Update to release 1.0.25

* Sun Mar 13 2022 ghibo <ghibo> 1.0.22-1.mga9
+ Revision: 1790836
- Update to release 1.0.22.
- Drop Patch103, merged upstream.

* Tue Dec 28 2021 ghibo <ghibo> 1.0.20-1.mga9
+ Revision: 1765088
- Update to release 1.0.20.
- Drop support for mageia7 cmake building.
- Refresh patchset.

* Fri Dec 04 2020 ghibo <ghibo> 1.0.13-2.mga8
+ Revision: 1652705
- Rebuilt because of missed signatures in the BS

* Mon Nov 30 2020 ghibo <ghibo> 1.0.13-1.mga8
+ Revision: 1650974
- Update to release 1.0.13

* Sat Sep 19 2020 ghibo <ghibo> 1.0.11-1.mga8
+ Revision: 1628769
- imported package openxr


* Sat Sep 19 2020 ghibo <ghibo> 1.0.11-1.mga8
- importing for blender.
- initial release.
